package sample.exception;

import sample.common.MessageCode;

/**
 * メッセージ表示を伴う例外をあらわす例外クラスです.
 *
 */
public class AppMessageException extends RuntimeException {

    /** default serialVersionUID. */
    private static final long serialVersionUID = 1L;
    
    
    /** 出力するメッセージ種別. */
    private MessageCode messageCode;
    
    /** 出力するメッセージの引数配列. */
    private String[] messageArgs;

    /**
     * {@link AppMessageException}を作成します.
     * @param code メッセージ種別
     * デフォルトコンストラクタ.
     */
    public AppMessageException(final MessageCode code) {
        this.messageCode = code;
    }

    /**
     * {@link AppMessageException}を作成します.
     * @param code メッセージ種別
     * @param message メッセージ
     */
    public AppMessageException(final MessageCode code, final String message) {
        super(message);
        this.messageCode = code;
    }

    /**
     * {@link AppMessageException}を作成します.
     * @param code メッセージ種別
     * @param cause 原因
     */
    public AppMessageException(final MessageCode code, final Throwable cause) {
        super(cause);
        this.messageCode = code;
    }

    /**
     * {@link AppMessageException}を作成します.
     * @param code メッセージ種別
     * @param message メッセージ
     * @param cause 例外
     */
    public AppMessageException(final MessageCode code,
                                final String message, final Throwable cause) {
        super(message, cause);
        this.messageCode = code;
    }


    /**
     * {@link AppMessageException}を作成します.
     * デフォルトコンストラクタ.
     * @param code メッセージ種別
     * @param args 引数の配列
     */
    public AppMessageException(final MessageCode code, final String[] args) {
        this.messageCode = code;
        this.messageArgs = args.clone();
    }

    /**
     * {@link AppMessageException}を作成します.
     * @param code メッセージ種別
     * @param args 引数の配列
     * @param message メッセージ
     */
    public AppMessageException(final MessageCode code, final String[] args,
                                final String message) {
        super(message);
        this.messageCode = code;
        this.messageArgs = args.clone();
    }

    /**
     * {@link AppMessageException}を作成します.
     * @param code メッセージ種別
     * @param args 引数の配列
     * @param cause 原因
     */
    public AppMessageException(final MessageCode code, final String[] args,
                                final Throwable cause) {
        super(cause);
        this.messageCode = code;
        this.messageArgs = args.clone();
    }

    /**
     * {@link AppMessageException}を作成します.
     * @param message メッセージ
     * @param code メッセージ種別
     * @param args 引数の配列
     * @param cause 例外
     */
    public AppMessageException(final MessageCode code, final String[] args,
                                final String message, final Throwable cause) {
        super(message, cause);
        this.messageCode = code;
        this.messageArgs = args.clone();
    }

    /**
     * 出力するメッセージの引数配列を取得します.
     * @return 出力するメッセージの引数配列
     */
    public String[] getMessageArgs() {
        if (messageArgs == null) {
            return null;
        }
        return messageArgs.clone();
    }

    /**
     * 出力するメッセージ種別を取得します.
     * @return 出力するメッセージ種別
     */
    public MessageCode getMessageCode() {
        return messageCode;
    }
    
}
