package sample.interceptor;

import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.faces.internal.FacesMessageUtil;

import org.aopalliance.intercept.MethodInvocation;
import org.seasar.framework.aop.interceptors.ThrowsInterceptor;

import sample.exception.AppMessageException;
import sample.web.error.ErrorPage;



/**
 * ページクラスで発生した例外を補足するためのインタセプタ.
 *
 */
public class PageThrowableInterceptor extends ThrowsInterceptor {

    /** serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /**
     * 例外を処理します.
     * @param ex 対象例外
     * @param invocation MethodInvocation
     * @return 遷移先
     */
    public Class handleThrowable(final AppMessageException ex,
                                  final MethodInvocation invocation) {
        final FacesContext context = FacesContext.getCurrentInstance();
        final FacesMessage facesMessage = FacesMessageUtil.getMessage(context,
                ex.getMessageCode().getCode(), ex.getMessageArgs());
        context.addMessage(null, facesMessage);
        Class result;
        switch (ex.getMessageCode().getType()) {
            case FATAL:
                result = ErrorPage.class;
                break;
            default:
                result = null;
                break;
        }
        return result;
    }

    /**
     * 例外を処理します.
     * @param ex 対象例外
     * @param invocation MethodInvocation
     * @return 遷移先
     */
    public Class handleThrowable(final RuntimeException ex,
                                  final MethodInvocation invocation) {
        // エラー画面への遷移
        // TODO エラーコードの設定
        return ErrorPage.class;
    }

}
